@@ -101,7 +101,8 @@ class API(object):
                 if self._debug:
                     print >>sys.stderr, "Login failed, page contents:\n%s" % page
                 raise APIException("Login failed, please check credentials (using %s)" % user)
-            self._team_id = matcher.group(1)
+            self.team_id = matcher.group(1)
+            self.user = user
         except urllib2.URLError as e:
             raise e
 
@@ -113,7 +114,7 @@ class API(object):
             kwargs['accept'] = 'application/json'
             kwargs['requestId'] = str(uuid.uuid4())
             kwargs['userLocale'] = 'en_US'
-            kwargs['teamId'] = self._team_id
+            kwargs['teamId'] = self.team_id
             query = urllib.urlencode(kwargs)
             url = "%s/%s?%s" % (self.DEVELOPER_SERVICES_URL, cmd, query)
             response = self._opener.open(url, form)
@@ -149,12 +150,14 @@ class API(object):
                 path = os.path.dirname(path)
 
         import ConfigParser
+        group = os.environ.get('PORTAL_ENVIRONMENT', 'Default')
         try:
             cfg = ConfigParser.RawConfigParser()
             cfg.read(search_path())
-            return cfg.get('Main', 'user'), cfg.get('Main', 'password')
+            return cfg.get(group, 'user'), cfg.get(group, 'password')
         except ConfigParser.Error:
-            raise APIException('Missing credentials (.portalrc / PORTAL_CREDENTIALS)')
+            raise APIException('Missing credentials '
+                '(.portalrc section [%s] / PORTAL_CREDENTIALS)' % group)
 
     def _list_cert_requests(self):
         data = self._api("certificate/listCertRequests", certificateStatus=0,
